@@ -2,42 +2,43 @@ import contextvars
 
 class ScopedContext:
     """
-    Holds scoped instances for the current context.
+    Manages scoped instances using Python's context variables, allowing for context-local storage of active scopes.
     """
+
     _active_scope = contextvars.ContextVar(
-        "orionis_scope",
+        "orionis_context_scope",
         default=None
     )
 
     @classmethod
     def getCurrentScope(cls):
         """
-        Get the currently active scope.
+        Retrieve the currently active scope for the current context.
 
         Returns
         -------
         object or None
-            The current active scope or None if no scope is active.
+            The currently active scope object, or None if no scope is set.
         """
         return cls._active_scope.get()
 
     @classmethod
     def setCurrentScope(cls, scope):
         """
-        Set the current active scope.
+        Set the active scope for the current context.
 
         Parameters
         ----------
         scope : object
-            The scope object to set as active.
+            The scope object to be set as the active scope for the current context.
         """
         cls._active_scope.set(scope)
 
     @classmethod
     def clear(cls):
         """
-        Clear the current active scope.
+        Clear the active scope for the current context.
 
-        Sets the active scope to None.
+        Resets the active scope to None.
         """
         cls._active_scope.set(None)
\ No newline at end of file
