@@ -6,42 +6,48 @@ from orionis.services.introspection.exceptions import ReflectionTypeError
 @dataclass(frozen=True, kw_only=True)
 class MethodDependency:
     """
-    Represents the dependencies of a method, separating resolved and unresolved dependencies.
+    Represents the dependencies of a method, distinguishing between resolved and unresolved dependencies.
 
     Parameters
     ----------
-    resolved : Dict[KnownDependency, Any]
-        A dictionary mapping resolved dependency descriptors to their corresponding
-        resolved instances or values for the method. All keys must be KnownDependency instances.
-    unresolved : List[str]
-        A list of method parameter names or dependency identifiers that could not be resolved.
-        Must contain only non-empty strings.
+    resolved : dict of KnownDependency to Any
+        Dictionary mapping each resolved KnownDependency to its corresponding instance or value.
+    unresolved : list of str
+        List of parameter names or dependency identifiers that could not be resolved.
 
     Raises
     ------
     ReflectionTypeError
-        If types don't match the expected:
-            - resolved: Dict[KnownDependency, Any]
-            - unresolved: List[str]
+        If `resolved` is not a dictionary with KnownDependency keys, or if `unresolved` is not a list of strings.
     ValueError
-        If resolved contains None keys or unresolved contains empty strings
+        If `resolved` contains None keys or `unresolved` contains empty strings.
+
+    Attributes
+    ----------
+    resolved : dict of KnownDependency to Any
+        The resolved dependencies for the method.
+    unresolved : list of str
+        The unresolved dependencies for the method.
     """
+
+    # Resolved dependencies mapped to their values
     resolved: Dict[KnownDependency, Any]
+
+    # Unresolved dependencies as a list of parameter names
     unresolved: List[str]
 
     def __post_init__(self):
         """
-        Validates types and values of attributes during initialization.
+        Validates the types and values of the attributes after initialization.
 
         Raises
         ------
         ReflectionTypeError
-            If types don't match the expected:
-                - resolved: Dict[KnownDependency, Any]
-                - unresolved: List[str]
+            If `resolved` is not a dictionary or `unresolved` is not a list.
         ValueError
-            If resolved contains None keys or unresolved contains empty strings
+            If `resolved` contains None keys or `unresolved` contains empty strings.
         """
+
         # Validate 'resolved' is a dict with proper key types
         if not isinstance(self.resolved, dict):
             raise ReflectionTypeError(
